@@ -2118,6 +2118,8 @@ class TestDataset(unittest.TestCase):
 
     def test_copyinplace(self):
         ds = Dataset()
+        # also check that len returns 0 instead of None
+        self.assertTrue(len(ds)==0)
         ds.MyStrKey = Categorical(list('ABCD'))
         ds.MyIntKey = [1, 2, 3, 4]
         ds.MyDate = Date([1, 2, 3, 4])
@@ -2126,6 +2128,11 @@ class TestDataset(unittest.TestCase):
         result = ds.cat(['MyStrKey', 'MyDate']).null()
         self.assertTrue(isinstance(result['MyDate'], Date))
 
+    def test_underscorename(self):
+        ds=Dataset()
+        ds.num=arange(10)
+        with self.assertRaises(IndexError):
+            ds['_num']=arange(10)        
 
 @pytest.mark.parametrize('categorical', get_all_categorical_data())
 def test_dataset_to_dataframe_roundtripping(categorical):
