@@ -2,6 +2,7 @@ import warnings
 import numpy as np
 import unittest
 import pytest
+import sys
 import riptable as rt
 import riptide_cpp as rc
 from numpy.testing import assert_equal
@@ -519,6 +520,14 @@ func_sets = {
     "unary_funcs": [key for key, value in gUnaryUFuncs.items() if value is not None],
     "logical_funcs": list(gBinaryLogicalUFuncs.keys()),  # we hook all of these
 }
+
+#remove power for darwin - the test will fail because different compilers have different overflows for small ints like uint16
+if sys.platform == 'darwin':
+    bfuncs = func_sets["binary_funcs"]
+    newbfuncs = [key for key in bfuncs if key is not np.power]
+    warnings.warn('power removed for MacOS test')
+    func_sets["binary_funcs"] = newbfuncs
+
 drivers = {
     "binary_funcs": static_binary,
     "unary_funcs": static_unary,
@@ -1439,7 +1448,19 @@ class FastArray_Test(unittest.TestCase):
         result = FastArray([1])[0] / FastArray([2])
         self.assertEqual(result, 0.5)
 
-
+    def test_int64_comparisons(self):
+        x=701389446541966656
+        y=rt.asarray([x-1,x,x+1,x,x,x]).astype(np.uint64)
+        z=rt.asarray([-x-1,-x,-x+1,x-1,x,x+1]).astype(np.int64)
+        r = y > z
+        self.assertTrue(np.all(r == [ True,  True,  True, True, False, False]))
+        r = y >= z
+        self.assertTrue(np.all(r == [ True,  True,  True, True, True, False]))
+        r = z < y
+        self.assertTrue(np.all(r == [ True,  True,  True, True, False, False]))
+        r = z == y
+        self.assertTrue(np.all(r == [ False,  False, False, False, True, False]))
+        
 # TODO: Extend the tests in the TestFastArrayNanmax / TestFastArrayNanmin classes below to cover the following cases:
 #   * non-array inputs (e.g. a list or set or scalar)
 #   * other FastArray subclass, e.g. Date
